logtailor package
=================

Submodules
----------

logtailor.logtailor module
--------------------------

.. automodule:: logtailor.logtailor
   :members:
   :undoc-members:
   :show-inheritance:

logtailor.processors module
---------------------------

.. automodule:: logtailor.processors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: logtailor
   :members:
   :undoc-members:
   :show-inheritance:
